#!/usr/bin/python
# -*- coding: utf-8 -*-
#################################################################################
# LAYMAN VERSION
#################################################################################
# File:       version.py
#
#             Current version number
#
# Copyright:
#             (c) 2005 - 2009 Gunnar Wrobel
#             (c) 2009        Sebastian Pipping
#             (c) 2011        Brian Dolbec
#             Distributed under the terms of the GNU General Public License v2
#
# Author(s):
#             Gunnar Wrobel <wrobel@gentoo.org>
#             Sebastian Pipping <sebastian@pipping.org>
#             Brian Dolbec <brian.dolbec@gmail.com>
#

from __future__ import unicode_literals

__version__ = "$Id: version.py 309 2007-04-09 16:23:38Z wrobel $"


VERSION = '2.1.0'

if __name__ == '__main__':
    print(VERSION)
